@@ -4,6 +4,8 @@
 #TODO
 #import asyncio
 import datetime
+#TODO
+print(f"got here init 0 - {datetime.datetime.now()}")
 import fastnumbers
 import glob
 import gzip
@@ -24,7 +26,7 @@ import sys
 import tempfile
 import zstandard
 
-print("got here init")
+print(f"got here init 1 - {datetime.datetime.now()}")
 
 #from . Builder import testme
 
@@ -35,4 +37,6 @@ from f4.Builder import *
 from f4.Filters import *
 from f4.IndexBuilder import *
 from f4.IndexSearcher import *
-from f4.Parser import *
\ No newline at end of file
+from f4.Parser import *
+
+print(f"got here init 2 - {datetime.datetime.now()}")
\ No newline at end of file
